TestArgs

Struct TestArgs 

pub struct TestArgs {
    pub path: Option<String>,
    pub go: bool,
    pub wasm: bool,
    pub chain_simulator: bool,
    pub scen: bool,
    pub nocapture: bool,
}

Fields

path: Option<String>

Target directory where to generate contract integration tests (default: current directory)

go: bool

Run Debugger (Rust-only) and Go tests; deprecated in favor of -w or –wasm (default: “false”)

wasm: bool

Run tests that are based on compiled contracts (default: “false”)

chain_simulator: bool

Run interactor tests using chain simulator (default: “false”)

scen: bool

Run mx-scenario-go (default: “false”) Overrides other arguments

nocapture: bool

Print the entire output from the Rust tests (default: “false”)